@@ -12,4 +12,4 @@
 #
 ##############################################################################
 from zope.i18nmessageid import MessageFactory
-MessageFactory = MessageFactory('ore.yuiwidget') 
+_ = MessageFactory('ore.yuiwidget') 
